pynormaliz: Python bindings for the normaliz library
====================================================

Description
-----------

The Python module PyNormaliz provides wrappers for normaliz.

License
-------

-  GPL v2 or later


Upstream Contact
----------------

   https://github.com/sebasguts/PyNormaliz

Dependencies
------------

-  pip
-  normaliz


Special Update/Build Instructions
---------------------------------
